package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`MP`!````@"$```````!``````````%BU````
M`````````$``.``(`$``&@`9``8````$````0`````````!``````````$``
M````````P`$```````#``0````````@``````````P````0``````@``````
M```"``````````(````````7`````````!<``````````0`````````!````
M!0```````````````````````````````````"2?````````))\`````````
M``$```````$````&````0*T```````!`K0$``````$"M`0``````4`4`````
M```(!@```````````0```````@````8```!8K0```````%BM`0``````6*T!
M``````#@`0```````.`!````````"``````````$````!````!@"````````
M&`(````````8`@```````"P`````````+``````````$`````````%#E=&0$
M````6)<```````!8EP```````%B7````````!`$````````$`0````````0`
M````````4N5T9`0```!`K0```````$"M`0``````0*T!``````#``@``````
M`,`"`````````0`````````O=7-R+VQI8F5X96,O;&0N96QF7W-O```'````
M!`````$```!.971"4T0```#*FCL$````!`````,```!085@```````````!A
M````:0``````````````,@````X``````````````#D````/````00``````
M```Q``````````,```!-````8@`````````@````3`````8````>````%0``
M``````!#````5P```%X`````````&````#T```!9``````````````!E````
M9P```#`````3````6````$4````6````70```$8`````````20```",````V
M````7````"<````K``````````<```!/``````````P````M````:````%L`
M``!+````(0```%````!F`````````&``````````&0```"\```!.````````
M````````````$@```#0`````````"@```&$````L``````````D`````````
M)0```#H`````````40````4```!'````'````#P`````````````````````
M````2@`````````[````5````&,`````````9```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````4````````````````````````````````
M````````````````````)````"(`````````*@`````````+````*````"D`
M```N```````````````-`````````!T````;````&@``````````````$0``
M```````U````,P```#@````?``````````````````````````0`````````
M`````$(````F````````````````````%P``````````````0````$0````(
M````````````````````/P```%,``````````````%8``````````````#X`
M`````````````%(`````````2````!``````````50```%H````W````7P``
M`````````````````````````````````````````````P`*`(`A````````
M`````````````````P`0`%"M`0````````````````"9````$@``````````
M```````````````,````$@`````````````````````````4````$@``````
M``````````````````!W`P``$@`*`(`K````````"``````````<````(@``
M```````````````````````K````$@`````````````````````````>`P``
M$@`````````````````````````Q````$@````````````````````````!0
M`P``$``5`)"R`0`````````````````X````$@``````````````````````
M``"(`P``$@`*`)`U````````(``````````_````$@``````````````````
M```````K`P``$@````````````````````````!'````$@``````````````
M``````````"C`P``$@`*`/`^````````:`````````"*````$@``````````
M``````````````!?`P``$``5`$BS`0````````````````!/````$@``````
M``````````````````"O`P``$``4`)"R`0````````````````!?````$@``
M``````````````````````!N````$@````````````````````````!T````
M$@````````````````````````![````$@````````````````````````"%
M````$@````````````````````````"/````$@``````````````````````
M``!>`P``$``5`$BS`0````````````````"8````$@``````````````````
M```````:`@``$@````````````````````````">````$@``````````````
M``````````"E````$@````````````````````````"S````$@``````````
M``````````````#$````$0````````````````````````"O`@``(@``````
M``````````````````#1````$@````````````````````````"V`P``$@`*
M`+0M````````+`````````##`P``$@`*`.`M````````;`````````#/`P``
M$@`*`-0V````````Q`4```````#?````%@````````````````````````#R
M````$@`````````````````````````]`P``$@``````````````````````
M``#]````$@`````````````````````````&`0``$0`5`$"S`0``````"```
M```````.`0``$@`````````````````````````7`0``$@``````````````
M```````````4`P``$@`````````````````````````C`0``$@``````````
M```````````````J`0``$@````````````````````````#<`P``$@`*`$!0
M````````*`$````````]`0``$0````````````````````````!/`0``$@``
M``````````````````````!?`0``$@````````````````````````!M`0``
M$@````````````````````````!R`0``$@````````````````````````#G
M`P``$0`4`(BR`0``````"`````````"!`0``$@``````````````````````
M``"-`0``$@````````````````````````"B`0``$@``````````````````
M``````"M`0``$@````````````````````````!R`P``$``5`$BS`0``````
M``````````#5`@``$@````````````````````````#``0``$@``````````
M```````````````B!```$@`*`(`A````````"`````````#.`0``$@``````
M``````````````````#6`0``$@````````````````````````#B`0``$@``
M``````````````````````!J`P``$``5`$BS`0````````````````#Q`P``
M$@`*`%`N````````Q`0```````#H`0``$@````````````````````````#S
M`0``$@````````````````````````#^`P``$@`*`'!1````````E`$`````
M```$`@``$@`````````````````````````(!```$``5`)"R`0``````````
M```````4!```$@`*`.0J````````0``````````<!```$@`*`-!3````````
M&`(````````+`@``$@````````````````````````"0`@``(@``````````
M```````````````A!```$@`*`(`A````````"``````````2`@``$@``````
M```````````````````I!```$@`*`)`K````````)`(````````V!```$@`*
M`+`U````````)`$````````9`@``$@````````````````````````!(!```
M$@`*`!0S````````<``````````B`@``$@````````````````````````"H
M`@``$@`````````````````````````S`@``$@``````````````````````
M``!6!```$@`*`(0S````````G`````````!"`@``$@``````````````````
M``````!+`@``$@````````````````````````!1`@``$@``````````````
M```````````'`P``$@````````````````````````!6`@``$@``````````
M``````````````#Z`@``$0`5`,BR`0``````"`````````!>`@``$@``````
M```````````````````R`P``$@````````````````````````!E`@``$@``
M``````````````````````!>!```$@`*`.1/````````5`````````!L`@``
M$0````````````````````````#O`@``$0`4``BR`0``````"`````````!G
M!```$@`*`*`\````````2`(````````V`0``$@``````````````````````
M``!Q`@``$@````````````````````````!$`P``$@``````````````````
M````````;&EB<&5R;"YS;P!R96%L;&]C`&UE;6UO=F4`7U]C>&%?9FEN86QI
M>F4`<FUD:7(`<W1R<W1R`'-T<F-H<@!S=')N8VUP`'-T<G)C:'(`8F]O=%]$
M>6YA3&]A9&5R`'!E<FQ?8V]N<W1R=6-T`&%B;W)T`'5N;&EN:P!?7VQS=&%T
M-3``<&5R;%]F<F5E`%]?<W1A=#4P`%]E>&ET`&UE;6-P>0!P97)L7V1E<W1R
M=6-T`%]?<W1A8VM?8VAK7V9A:6P`4$Q?9&]?=6YD=6UP`%!E<FQ?<W9?<V5T
M<'8`4$Q?8W5R<F5N=%]C;VYT97AT`'!E<FQ?86QL;V,`8VQO<V5D:7(`96YV
M:7)O;@!R96%D;&EN:P!?7V]P96YD:7(S,`!M96US970`4&5R;%]S869E<WES
M;6%L;&]C`%]?<W1A8VM?8VAK7V=U87)D`%!E<FQ?9W9?9F5T8VAP=@!?7W-P
M<FEN=&9?8VAK`')E860`4&5R;%]S>7-?:6YI=#,`4&5R;%]G971?<W8`4&5R
M;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%]N97=84P!097)L7V%T9F]R:U]U;FQO
M8VL`4&5R;%]S>7-?=&5R;0!?7V5R<FYO`%!E<FQ?;6=?<V5T`&UK9&ER`'!E
M<FQ?<&%R<V4`4&5R;%]N97=84U]F;&%G<P!A8V-E<W,`9V5T<&ED`&UE;6-H
M<@!V9G!R:6YT9@!097)L7V%T9F]R:U]L;V-K`%!E<FQ?<W9?<V5T<'9N`'!E
M<FQ?<G5N`&QS965K`&]P96X`<W!R:6YT9@!G971U:60`<W1R;&5N`%]?<T8`
M<W1R8VUP`&QI8FTN<V\N,`!L:6)C<GEP="YS;RXQ`%]?9&5R96=I<W1E<E]F
M<F%M95]I;F9O`'-T<F1U<`!?7W)E9VES=&5R7V9R86UE7VEN9F\`;&EB<'1H
M<F5A9"YS;RXQ`'!T:')E861?871F;W)K`&QI8F,N<V\N,3(`7U]P<F]G;F%M
M90!?7W!S7W-T<FEN9W,`7U]G971P=W5I9#4P`%]?<WES8V%L;`!?7W-T<&-P
M>5]C:&L`871E>&ET`%]L:6)C7VEN:70`<W1R=&]K`%]?<F5A9&1I<C,P`%]?
M8G-S7W-T87)T7U\`7U]B<W-?96YD7U\`7U]E;F1?7P!?96YD`'!A<E]C=7)R
M96YT7V5X96,`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<&%R7V-L96%N
M=7``7V5D871A`'!A<E]B87-E;F%M90!P87)?9&ER;F%M90!P87)?;6MT;7!D
M:7(`<VAA7W5P9&%T90!M>5]P87)?<&P`<&%R7VEN:71?96YV`'-H85]F:6YA
M;`!?7V)S<U]S=&%R=`!X<U]I;FET`&UA:6X`7U]S=&%R=`!P87)?9FEN9'!R
M;V<`<&%R7W-E='5P7VQI8G!A=&@`<&%R7V5N=E]C;&5A;@!P87)?9&EE`'-H
M85]I;FET`%A37TEN=&5R;F%L<U]005)?0D]/5``O=7-R+W!K9R]L:6(O<&5R
M;#4O-2XS."XP+V%A<F-H-C0M;F5T8G-D+71H<F5A9"UM=6QT:2]#3U)%.B]U
M<W(O<&MG+VQI8@````!`K0$```````,$````````D%,```````!(K0$`````
M``,$````````$%,```````!`KP$```````,$````````4*T!``````!8KP$`
M``````,$````````0*T!``````!XKP$```````,$````````0+,!``````"(
MKP$```````,$````````2*T!``````"0KP$```````,$````````B+(!````
M``"PKP$```````,$````````6*T!``````#(KP$```````,$````````R+(!
M``````#8KP$```````,$````````"+(!``````#@KP$```````,$````````
MH#P````````(L@$```````,$````````P+(!```````0L@$```````,$````
M````$+(!```````HL@$```````,$`````````%8````````PL@$```````,$
M````````"%8```````!`L@$```````,$````````$%8```````!(L@$`````
M``,$````````(%8```````!0L@$```````,$````````*%8```````!8L@$`
M``````,$````````,%8```````!@L@$```````,$````````.%8```````!P
ML@$```````,$````````0%8```````!XL@$```````,$````````2%8`````
M``"(L@$```````,$````````T%D```````!(KP$```````$$```'````````
M``````!0KP$```````$$```4``````````````!@KP$```````$$```B````
M``````````!HKP$```````$$```C``````````````!PKP$```````8$```H
M``````````````"`KP$```````$$```S``````````````"8KP$```````$$
M```\``````````````"HKP$```````$$``!.``````````````#`KP$`````
M``$$``!5``````````````#0KP$```````$$``!C````````````````L`$`
M``````($```#```````````````(L`$```````($```$```````````````0
ML`$```````($```%```````````````8L`$```````($```'````````````
M```@L`$```````($```(```````````````HL`$```````($```)````````
M```````PL`$```````($```*```````````````XL`$```````($```,````
M``````````!`L`$```````($```.``````````````!(L`$```````($```/
M``````````````!0L`$```````($```0``````````````!8L`$```````($
M```2``````````````!@L`$```````($```6``````````````!HL`$`````
M``($```7``````````````!PL`$```````($```8``````````````!XL`$`
M``````($```9``````````````"`L`$```````($```:``````````````"(
ML`$```````($```;``````````````"0L`$```````($```=````````````
M``"8L`$```````($```>``````````````"@L`$```````($```?````````
M``````"HL`$```````($```@``````````````"PL`$```````($```A````
M``````````"XL`$```````($```C``````````````#`L`$```````($```D
M``````````````#(L`$```````($```I``````````````#0L`$```````($
M```J``````````````#8L`$```````($```K``````````````#@L`$`````
M``($```M``````````````#HL`$```````($```N``````````````#PL`$`
M``````($```O``````````````#XL`$```````($```P````````````````
ML0$```````($```Q```````````````(L0$```````($```T````````````
M```0L0$```````($```U```````````````8L0$```````($```V````````
M```````@L0$```````($```W```````````````HL0$```````($```Y````
M```````````PL0$```````($```Z```````````````XL0$```````($```[
M``````````````!`L0$```````($```^``````````````!(L0$```````($
M```_``````````````!0L0$```````($``!!``````````````!8L0$`````
M``($``!"``````````````!@L0$```````($``!#``````````````!HL0$`
M``````($``!&``````````````!PL0$```````($``!'``````````````!X
ML0$```````($``!)``````````````"`L0$```````($``!-````````````
M``"(L0$```````($``!.``````````````"0L0$```````($``!0````````
M``````"8L0$```````($``!3``````````````"@L0$```````($``!6````
M``````````"HL0$```````($``!7``````````````"PL0$```````($``!9
M``````````````"XL0$```````($``!:``````````````#`L0$```````($
M``!;``````````````#(L0$```````($``!<``````````````#0L0$`````
M``($``!=``````````````#8L0$```````($``!?``````````````#@L0$`
M``````($``!@``````````````#HL0$```````($``!A``````````````#P
ML0$```````($``!F``````````````#XL0$```````($``!G````````````
M````L@$```````($``!H`````````````````````````/![OZG0``"P$?Y'
M^1#B/Y$@`A_6'R`#U1\@`]4?(`/5T```T!$"0/D0`@"1(`(?UM```-`1!D#Y
M$"(`D2`"'];0``#0$0I`^1!"`)$@`A_6T```T!$.0/D08@"1(`(?UM```-`1
M$D#Y$((`D2`"'];0``#0$19`^1"B`)$@`A_6T```T!$:0/D0P@"1(`(?UM``
M`-`1'D#Y$.(`D2`"'];0``#0$2)`^1`"`9$@`A_6T```T!$F0/D0(@&1(`(?
MUM```-`1*D#Y$$(!D2`"'];0``#0$2Y`^1!B`9$@`A_6T```T!$R0/D0@@&1
M(`(?UM```-`1-D#Y$*(!D2`"'];0``#0$3I`^1#"`9$@`A_6T```T!$^0/D0
MX@&1(`(?UM```-`10D#Y$`("D2`"'];0``#0$49`^1`B`I$@`A_6T```T!%*
M0/D00@*1(`(?UM```-`13D#Y$&("D2`"'];0``#0$5)`^1""`I$@`A_6T```
MT!%60/D0H@*1(`(?UM```-`16D#Y$,("D2`"'];0``#0$5Y`^1#B`I$@`A_6
MT```T!%B0/D0`@.1(`(?UM```-`19D#Y$"(#D2`"'];0``#0$6I`^1!"`Y$@
M`A_6T```T!%N0/D08@.1(`(?UM```-`1<D#Y$((#D2`"'];0``#0$79`^1"B
M`Y$@`A_6T```T!%Z0/D0P@.1(`(?UM```-`1?D#Y$.(#D2`"'];0``#0$8)`
M^1`"!)$@`A_6T```T!&&0/D0(@21(`(?UM```-`1BD#Y$$($D2`"'];0``#0
M$8Y`^1!B!)$@`A_6T```T!&20/D0@@21(`(?UM```-`1ED#Y$*($D2`"'];0
M``#0$9I`^1#"!)$@`A_6T```T!&>0/D0X@21(`(?UM```-`1HD#Y$`(%D2`"
M'];0``"P$:9`^1`B!9$@`A_6T```L!&J0/D00@61(`(?UM```+`1KD#Y$&(%
MD2`"'];0``"P$;)`^1""!9$@`A_6T```L!&V0/D0H@61(`(?UM```+`1ND#Y
M$,(%D2`"'];0``"P$;Y`^1#B!9$@`A_6T```L!'"0/D0`@:1(`(?UM```+`1
MQD#Y$"(&D2`"'];0``"P$<I`^1!"!I$@`A_6T```L!'.0/D08@:1(`(?UM``
M`+`1TD#Y$((&D2`"'];0``"P$=9`^1"B!I$@`A_6T```L!':0/D0P@:1(`(?
MUM```+`1WD#Y$.(&D2`"'];0``"P$>)`^1`"!Y$@`A_6T```L!'F0/D0(@>1
M(`(?UM```+`1ZD#Y$$('D2`"'];0``"P$>Y`^1!B!Y$@`A_6T```L!'R0/D0
M@@>1(`(?UM```+`1]D#Y$*('D2`"'];0``"P$?I`^1#"!Y$@`A_6T```L!'^
M0/D0X@>1(`(?UM```+`1`D'Y$`((D2`"'];A`P*J-```%```````````_7N]
MJ<```)#]`P"1`*!'^?43`/G5``"0M2(UD;\"`.N"`0!4\U,!J10$`-&4`A7+
M$P"`TI3^0].@>G/X```_UG\"%.MS!@"1@?__5/-30:GU$T#Y_7O#J,`#7]8?
M(`/5_7N]J?T#`)'S4P&ITP``D/43`/G5``"0<])'^;7>1_E_`A7K8@$`5&`*
M0+D?(!#Q@0$`5'0"0/ES8@"18()?^```/]:``@#Y?P(5Z^/^_U3S4T&I]1-`
M^?U[PZC``U_6_/[_E_U[O*G]`P"1\U,!J?5;`JGW&P#Y80D`M/0#`:K!``"0
MU0``D"'D1_F"`D#YI+Y'^4,`0/DT``#Y@0I`^8$``/G!``"0(P<`M"'L1_DC
M``#Y0@!`^4,`0#GC```T0@0`D7^\`'&!__]4(@``^4,`0#EC__\U0```M,W^
M_Y>8__^7P```D`#81_G`!@"TP```D-<``)#W`C61`*Q'^?\"`.M"`0!4%@0`
MT1,`@-+6`A?+UOY#T^!Z<_@``#_6?P(6ZW,&`)&!__]4````D`!`!I&W_O^7
MUP``D,```)#W`C61`,1'^?\"`.M"`0!4%@0`T1,`@-+6`A?+UOY#T^!Z<_@`
M`#_6WP(3ZW,&`)&!__]4M;Y'^8`*0+F!`D#YH@)`^1<,`)1^_O^7(>Q'^<(`
M`+!"``N1(@``^0#Z_[70__\7`@``\$*@%Y%C`H#200"`4H``@-+J_O^7(`"`
M4KC^_Y>/__^7RO__%P````#]>[RI_0,`D?-3`:F@!@"T]V,#J?<#`*K```"0
M`+Q'^1@`0/DX!@"T]5L"J?8#`:H5`(!2X`)`.1_T`'$$&$!ZP0(`5!,#0/G3
M`0"TM7Y`D_0#&*H?(`/5X@,5JN$#%ZK@`Q.J<_[_EX```#5@:G4X'_0`<0`"
M`%23CD#X\_[_M?5;0JGW8T.IX`,3JO-30:G]>\2HP`-?UO4#%ZJ@'D`X'_0`
M<0080'JA__]4M0(72^7__Q>4`AC+M08`D7,"%8N4_D.3U`(`N>`#$ZKS4T&I
M]5M"J?=C0ZG]>\2HP`-?UA,`@-+I__\7$P"`TO=C0ZGF__\7_7NRJ<$``)#]
M`P"1(<!'^2(`0/GB;P#Y`@"`TL```+3S4P&I\P,`J@$`0#EA`0`U\U-!J<``
M`)``P$?YX6]`^0(`0/DA``+K`@"`TN$(`%3]>\ZHP`-?UHW^_Y?T`P"J@/[_
MM/=C`ZD7``#P^`,!D?=B&9'U6P*IX`,4JA#__Y<@!0"T`31`.14T`)$_N`!Q
M80``5*$&0#D!__\T`#1`.1^X`'$`!0!4X`,3JOC^_Y?V`P"JX`,5JO7^_Y?`
M`@`+``@`$0!\0)/U_O^7XP,5JN(#$ZKU`P"JX0,7JN#^_Y?A`QBJX`,5JCG^
M_Y<?!``QH```5.!+0+D`#!02'Q!`<>`"`%3@`Q6J)?[_E^`#%:H7_O^7X`,4
MJNG^_Y=`^_^U'R`#U>`#%*I1_O^7X`,3JO/]_Y?S4T&I]5M"J?=C0ZF]__\7
MH`9`.1^X`''A^O]4H`I`.2#Y_S34__\7X`,5JJC__Y?J__\7\U,!J?5;`JGW
M8P.I*O[_EQ\@`]7]>[2IP@``D/T#`)%"P$?Y\PL`^>&#`)'S`P"J0P!`^>-?
M`/D#`(#2`O[_ER`"`#7A*T"Y`@"44B$,%!(_$$!Q)!!">J`!`%3!``"0(<!'
M^>)?0/DC`$#Y0@`#ZP,`@-*!`0!4\PM`^?U[S*C``U_6``"`4O7__Q?@`Q.J
M00"`4FS^_Y<?``!QX!>?&N___Q<$_O^7_\,0T<,``)#A`P"J`H"`TOU[`*G]
M`P"18\!'^?,+`/GSHP"19`!`^>07`OD$`(#2X`,3JK+]_Y<`!`#1'P`3ZZ@`
M`%0'```4'_0?.!\`$^N```!4`0!`.3^\`'%@__]4X`,3JN$%@%*Y_?^70`(`
MM!\`$^O(`0!4X`,3JES^_Y?!``"0(<!'^>(70ODC`$#Y0@`#ZP,`@-*!`@!4
M_7M`J?,+0/G_PQ"1P`-?UA\``#GR__\7P```D`#`1_GA%T+Y`@!`^2$``NL"
M`(#2X0``5/U[0*D```#P\PM`^0`@&)'_PQ"10O[_%\G]_Y?_`Q'1PP``D.)_
M@-+]>P"I_0,`D6/`1_GS4P&I]`,`JO5;`JGUXP"1]@,!JF``0/G@'P+Y``"`
MTN$#%:H```#P`(`9D<_]_Y<?``!QS0(`5`,$`%&ARF,X`04`-4,"`#1S?$"3
MX`,5JN(#$ZKA!8!2'/[_EX`!`+1$T#O5P```D`"X1_D?(`/5'R`#U>,#$ZKB
M`Q6JX0,4JH!H8/@=_O^7"@``%$/0.]7```"0`+A'^1\@`]4?(`/5X@,6JN$#
M%*I@:&#XG_W_E\```)``P$?YX1]"^0(`0/DA``+K`@"`T@$!`%3]>T"I\U-!
MJ?5;0JG_`Q&1P`-?UN,#`"K9__\7B/W_E_U[NJG"``"0_0,`D?-3`:GS`P"J
M]`,!JO5;`JGW8P.I0L!'^2``0#E!`$#YX2\`^0$`@-(?]`!QE!:4FN`#%*H3
M_O^7]@,`JN%3`9'@`Q.JK_[_EV`(`+3U`P"J#/[_E]\"`.L)!P!4]U>`N=@`
M`)#W\GW38`)`.1_T`'$$&$!Z8`P`5.,#$ZH?(`/58AQ`.%_T`'%$&$!ZH?__
M5&,`$\MC?$"3&+]'^<`*`)$```.+%@-`^?K]_Y?`:C?XP`(`M.-7@+G@`Q.J
M`@-`^0$40#A#>&/X/_0`<2080'IA```YP```5`(40#AB'``X7_0`<4080'J!
M__]4H0>`4@``@-)A%``X@FI@.&)H(#@`!`"1HO__-<```)``P$?YX2]`^0(`
M0/DA``+K`@"`TJ$'`%3S4T&I]5M"J?=C0ZG]>\:HP`-?U@$`@-(?(`/5@FIA
M.*)J(3@A!`"1HO__->[__Q?8``"0^6L$J0"_1_D:`$#Y0`-`^0`%`+3@`QJJ
M%0"`4A\@`]4!C$#XX@,5*K4&`!&A__^U0`P`$0!\?9/!``"P(B!#N2("`#4B
M`(!2(B`#N;O]_Y?Y`P"J@`,`M+=^?9/A`QJJX@,7JL7\_Y<`OT?Y&0``^:`&
M`!$_VR#X]5<`N?EK1*FD__\7X0,`JN`#&JJW_/^7^0,`J@&_1_D@``#Y0`$`
MM+=^?9/S__\7`P"`TJ7__Q<``H#2%0"`4N#__Q?Y:P2I_OS_E_EK1*FZ__\7
M_7N_J4'0.]7"``"0_0,`D<```)``N$?Y'R`#U1\@`]7]>\&H(P``\$*H1_EC
M`!V1(&A@^`$``/`AX!F1,/W_%_U[OJE!T#O5_0,`D?,+`/G```"0`+A'^1\@
M`]4?(`/5,P``BR!H8/CF__^7P@``D`0``/!@`D#YA.`FD?,+0/GC`P2J_7O"
MJ`$``/!"\$?Y(6`:D04`@%(U_?\7``"`TL`#7]8?(`/5'R`#U?\#%-'"``"0
M_7L`J?T#`)%"P$?Y\U,!J?,#`:KU6P*IX7,!D?4#`*I#`$#YXW\"^0,`@-(`
M``#P`,`:D?W]_Y?T`P"JX06`4N`#%:J!_/^70`(`M.$#%:H```#P```;D3'_
M_Y?@`Q6JP0``D"'`1_GB?T+Y(P!`^4(``^L#`(#2P0P`5/U[0*GS4T&I]5M"
MJ?\#%)'``U_6X`,3JB']_Y<6``#PP4(;D;;\_Y?S`P"J(/W_M/=C`ZD8``#P
M%P``\!@C&)'W8AN1^2,`^1\@`]5@`D`YX`8`-+0``+3A`Q.JX`,4JCO]_Y=`
M!0`TX`,3JC#]_Y<"!`#1^0,`JF("`HM_`@+KHP``5`H``!1?]!\X?P("ZX``
M`%1!`$`Y/[P`<6#__U3@`Q.J(OW_E_D#`*K@`Q6J'_W_EQD`&8LY!P"1/_\/
M\0@#`%3D`Q.JY@,5JN4#%ZH#``#P8X`;D?/C`Y$"@(#2`0"`4N`#$ZJE_/^7
MX`,3JN&#`9%>_/^7H```->!K0+D`#!02'R!`<6`"`%3!0AN1``"`TGK\_Y?S
M`P"J@/G_M?=C0ZGY(T#YJO__%_0"`+2``D`Y'[@`<8```%3S`QBJ.0"`TMK_
M_Q>`!D`Y`/[_-/O__Q?@`Q.J(0"`4KS\_Y=@_?\UX0,3J@```/```!N1S/[_
ME^`#$ZK)_/^7]V-#J?DC0/F8__\7\P,8JCD`@-+'__\7]V,#J?DC`/E(_/^7
M_7N^J>$%@%+]`P"1\PL`^?,#`*H2_/^7'P``\6`&@)KS"T#Y_7O"J+7\_Q<`
M`P"T_7N^J?T#`)'S"P#Y\P,`J@$`0#DA`0`TT?S_EP`$`)$?`!#Q2`$`5.`#
M$ZKS"T#Y_7O"J"O^_Q?S"T#Y````\/U[PJ@`(!B1H?S_%P``@-+S"T#Y_7O"
MJ,`#7]8```#P`"`8D9K\_Q<?(`/5_7NZJ<```)#]`P"1`,!'^?5;`JG5``"0
M\U,!J10``/#S4P&1]V,#J92B&Y'Y(P#YM;Y'^0$`0/GA+P#Y`0"`TN$#$ZK@
M`Q2J2OW_E^`!`+2B`D#YXU>`N4`,`XL!!$#Y07@C^.'^_[0!"$#Y`00`^0`@
M`)&A__^UX0,3JN`#%*H\_?^78/[_M=4``)`4``#PE.(;D;6^1_GA`Q.JX`,4
MJC3]_Y?@`0"TH@)`^>-7@+E`#`.+`01`^4%X(_CA_O^T`0A`^0$$`/D`(`"1
MH?__M>$#$ZK@`Q2J)OW_EV#^_[75``"0%```\)0"')&UOD?YX0,3JN`#%*H>
M_?^7X`$`M*("0/GC5X"Y0`P#BP$$0/E!>"/XX?[_M`$(0/D!!`#Y`"``D:'_
M_[7A`Q.JX`,4JA#]_Y=@_O^UU0``D!0``/"40AR1M;Y'^>$#$ZK@`Q2J"/W_
ME^`!`+2B`D#YXU>`N4`,`XL!!$#Y07@C^.'^_[0!"$#Y`00`^0`@`)&A__^U
MX0,3JN`#%*KZ_/^78/[_M=4``)`4``#PEF(<D;6^1_GA`Q.JX`,6JO+\_Y?@
M`0"TH@)`^>-7@+E`#`.+`01`^4%X(_CA_O^T`0A`^0$$`/D`(`"1H?__M>$#
M$ZK@`Q:JY/S_EV#^_[6V``#P%0``T+6B')'6OD?YX0,3JN`#%:K<_/^7X`$`
MM,("0/GC5X"Y0`P#BP$$0/E!>"/XX?[_M`$(0/D!!`#Y`"``D:'__[7A`Q.J
MX`,5JL[\_Y=@_O^UM@``\!4``-"WPAJ1UKY'^>$#$ZK@`Q>JQOS_E^`!`+3"
M`D#YXU>`N4`,`XL!!$#Y07@C^.'^_[0!"$#Y`00`^0`@`)&A__^UX0,3JN`#
M%ZJX_/^78/[_M;<``/`6``#0V.(<D?>^1_GA`Q.JX`,8JK#\_Y?@`0"TX@)`
M^>-7@+E`#`.+`01`^4%X(_CA_O^T`0A`^0$$`/D`(`"1H?__M>$#$ZK@`QBJ
MHOS_EV#^_[6X``#P%P``T/DB'9$8OT?YX0,3JN`#&:J:_/^7X`$`M`(#0/GC
M5X"Y0`P#BP$$0/E!>"/XX?[_M`$(0/D!!`#Y`"``D:'__[7A`Q.JX`,9JHS\
M_Y=@_O^UN0``\!@``-`88QV1.;]'^>$#$ZK@`QBJA/S_E^`!`+0B`T#YXU>`
MN4`,`XL!!$#Y07@C^.'^_[0!"$#Y`00`^0`@`)&A__^UX0,3JN`#&*IV_/^7
M8/[_M;D``/`8``#0&`,;D3F_1_GA`Q.JX`,8JF[\_Y?@`0"T(@-`^>-7@+E`
M#`.+`01`^4%X(_CA_O^T`0A`^0$$`/D`(`"1H?__M>$#$ZK@`QBJ8/S_EV#^
M_[7A`Q.J````T`"@'9%;_/^7X0,`JF```+3@(AV1E/W_E^$#$ZH```#0```>
MD5/\_Y?A`P"J@```M````-``0!B1B_W_E^$#$ZH```#0`&`>D4K\_Y?A`P"J
M8`(`M*#"&I&#_?^7H```\`#`1_GA+T#Y`@!`^2$``NL"`(#280(`5(!B')$!
M``#0\U-!J2$`'Y'U6T*I]V-#J?DC0/G]>\:H<_W_%^$#$ZH```#0`*`>D3+\
M_Y?A`P"J8/W_M,#B')%K_?^7Z/__%_#Z_Y?]>[ZIH@``\````-#]`P"10L!'
M^>%3`)$`X!R10P!`^>,/`/D#`(#2(?S_E\`!`+0``$`Y'\``<0080'K@!Y\:
MH0``\"'`1_GB#T#Y(P!`^4(``^L#`(#2H0``5/U[PJC``U_6``"`4O;__Q?4
M^O^7_7NNJ:@``/#L!H`2_0,`D0K!1_G@&X`][8,#D>$?@#WK#X`2Z$,`D>(C
M@#VI``#PXR>`/>0K@#WE+X`]YC.`/><W@#WABPZIX0,`JN(#"*KCDP^IY9L0
MJ>>/`/D@Z4?Y0P%`^>,O`/D#`(#2XX,$D>./`ZD`P`21[2<`^>PO"BGDET.I
MY!<!J>271*D$%0&I(_O_E^`?@%)5^O^7_T,!T:,``/#_0T#1`0"`TN1#0)%"
M`(!2_7L`J?T#`)%CP$?Y\U,!J?0#`"IE`$#YA20`^04`@-(B^_^7``0`T?,#
M`.L!/$"2<SY`DC-$D]H3`!/KQ`<`5/5;`JD6``#0%0&`TM9B'Y'W8P.I%P``
MT/@#`9'W(A^1-0"@\A\@`]7A`Q.JX`,4*@(`@%(-^_^7'P0`L0`&`%3A`QBJ
MX@,5JN`#%"JW^O^7`7Q`DQ\$`#$`!`!4/QP`\0D$`%0A(`#1`0,!JZ(#`%3`
M``"0!```%"$$`-$_`!CK`P,`5`,,0?DB`$#Y?P`"ZT'__U0@`!C+]5M"J0``
M$XOW8T.IH0``\.)#0)$AP$?Y0R1`^20`0/EC``3K!`"`TD$"`%3]>T"I\U-!
MJ?]#`9'_0T"1P`-?UN`#%JJ,__^7<T)`T7]"0+$!^O]4]5M"J?=C0ZD``("2
MZ___%^`#%ZJ#__^7S___%_5;`JGW8P.I4OK_EQ\@`]7]>[^I_0,`D>+Z_Y?9
M^O^70```M```0/G]>\&HP`-?UOU[O*FB``#P_0,`D4+`1_GS4P&IX=,`D?5;
M`JD5``#0MJ(?D4,`0/GC'P#Y`P"`TO0#`*K@`Q:J=OO_EX```+0!`$`Y\P,`
MJL$!`#6@``#P`,!'^>$?0/D"`$#Y(0`"ZP(`@-+A!0!4X0,4JJ"B'Y'S4T&I
M]5M"J?U[Q*BB_/\7X0,4JN?Y_Y>``0"TH```\`#`1_GA'T#Y`@!`^2$``NL"
M`(#2X0,`5/-30:GU6T*I_7O$J,`#7];@`Q2JM?K_E_4#`*K@`Q.JLOK_EZ`"
M`(L`"`"1L_K_E^0#$ZKB`Q2J\P,`J@,``-`!``#08T`;D2&`&Y&;^O^7H@``
M\$+`1_G@'T#Y00!`^0```>L!`(#2@0``5.$#$ZK@`Q:JU?__%P#Z_Y?]>Z>I
MP@``D*$``/!"8`B1_0,`D2'`1_GS4P&IXR,"D?5;`JGSPP&1]6,!D?=C`ZGW
M`P"J]%,!D48<0:D@`$#YX,<`^0``@-)*K$*IYI\%J1@``-!(I$.IX0,4JD24
M1*D`PQJ13+1%J6@D`:E.$$#YK@H`^48T0/EF"@#Y9!0"J>PW!ZGJKPBI&?O_
MEX```+0!`$`Y]@,`JN$>`#7Y:P2IA___E_D#`*K`&P"TX`,9JF_Z_Y<`^'_3
M``0`D7#Z_Y<B`T`Y]@,`JF(!`#0:``#0\P,6JEH#()$?(`/5X`,3JN$#&JI6
M^O^7<PH`D2(?0#AB__\U`0``T/E#`I$@0!B1`P``%""'0/A`"`"TX0,4JO?Z
M_Y?S`P"J8/__M`$`0#DA__\TCOO_E^#^_S3@`Q.J*_K_E_,#`*K`!@"TX`,3
MJDOZ_Y?U`P"JX`,6JDCZ_Y>Y`@`+.1,0$1H``-`Y?T"3X`,9JD;Z_Y?E`Q:J
MX@,3JD-C&Y$$``#0A"`@D?4#`*H!``#0(4`@D2WZ_Y?@`Q6J`3B`4O+Y_Y<?
M!``Q`!(`5.'C`I'@`Q6J>?G_E_,#`"H@!0`TH```\`$``-#B`D#YXP,5J@#H
M1_DA@"&1%`"`T@#`!)%^^?^7H```\`#`1_GAQT#Y`@!`^2$``NL"`(#201X`
M5.`#%*KS4T&I]5M"J?=C0ZGY:T2I_7O9J,`#7]89`(!2L]IY^+,!`+1@`D`Y
M8`$`-#D'`!'@`Q.J3/O_ER#__S3@`Q.JZ?G_E_,#`*K@]_^UL]IY^+/^_[43
M`(#2N___%^##0+D`#!02'Q!`<:'Z_U3VUT"Y^?G_E]\"`&LA^O]4X,-`N0`@
M`!(?``=QH?G_5.`#&:K]^?^7X0,4JO0#`*H```#0`.`BD93Z_Y?A`P"J0!``
MM.`"0/F$_/^7^0,`JL`/`+3@`QFJ[/G_E_8#`*H?#`!Q[0$`5`!\0),!``#0
M`!``T2$`(Y$@`P"+Z_G_EP`!`#7?$@!QH!0`5-86`%$@RW8X'[P`<2`4`%0?
M(`/53_[_E\```#7@`QFJ`0"`4L+Y_Y?V`P`JP`P`-0$``-````#0(0`?D0#@
M')&L^_^76F,;D1<``-#WXB:1E_G_EQD``-#D`P`JY0,7JN,#&JKB`Q6JX`,4
MJ@$``-`Y`R21(<`CD;7Y_Y</```4<_G_EP``0+D?1`!Q`0(`5(?Y_Y=S!@`1
MY`,`*N4#$RKF`Q>JXP,:JN(#%:KA`QFJX`,4JJ;Y_Y?@`Q2J`3B`4FOY_Y<?
M!``QP/W_5.`#%:KC^/^7X0,4J@##&I&%^_^7X`,4JL+^_Y>`__\76/G_EP``
M0+D?1`!QP.W_5/,"0/E3^?^7I0``\`0`0+GB`Q.JXP,5JJ7H1_D4`(#2`0``
MT"&`()&@P`21[?C_EV___Q<6`(!28-IV^(`!`+3A`Q2JU@8`$2[Z_Y=@__^T
M`0!`.2'__S1F^?^7^0,`J@#C_[5@VG;XP/[_M:`!@-*(^?^7&0``T/8#`*HY
MXQ^18@J`4A?__Q>:_O^7H```\`#`1_GAQT#Y`@!`^2$``NL"`(#280D`5.`#
M%JKS4T&I]5M"J?=C0ZG]>]FH3?G_%_D"0/F"__\7)O[_E_<#`*H@\_^W`2@`
MT0(`@%+@`Q8J^4,%D4_Y_Y?A`QFJX`,6*L(`@-+[^/^7'Q@`\8```%0```#0
M`$`CD>_]_Y?A4T&Y`&"(4B!HJ'(_``!KP?#_5"$+0'D`J8A2/P``:T'P_U3A
MR@#1`@"`4N`#%BKS8P61./G_E^`#%BKA`Q.J`@6`TN3X_Y<?H`#Q@```5```
M`-``0".1V/W_E^0#$ZI#8QN1X@,5JN`#%*H%``#0`0``T*7@)I$A@".1_P,&
M.3'Y_Y>0__\7]@9`^1;L_[3@`Q:J./G_EQ\,`/&)Z_]4`!``T0$``-#``@"+
M(2`CD3GY_Y<?``!Q.1.6FE3__Q>1^/^7^6L$J8_X_Y<?(`/5'R`#U?U[NZFB
M``#P!```T/T#`)'S4P&I4]`[U:```/``N$?Y'R`#U1\@`]7U6P*I]1,!D>$#
M%:KW&P#Y0L!'^6-J8/B`8!R110!`^>4G`/D%`(#29,!".63$`CFR^?^7@```
MM`$`0#D_Q`!Q@`L`5%'\_Y>@``#P`+A'^1\@`]4?(`/5=@(`BV!J8/@!``#0
M8P"`4B%@))$B`(!2DOC_E_0#`*I@`0"T`0A`^0(``-#``D#Y0H`DD2$`0/EF
M^/^7@`I`^0$`0/D@#$"YH`JP-Z```/``N$?Y'R`#U1\@`]5W`@"+8&I@^`$`
M`-!C`(!2(:`DD2(`@%+6``"0>OC_E_0#`*I@`0"TX0,5J@```-```!N1A/G_
ME^(#`*I`!P"T@0I`^>`"0/DA`$#Y2OC_EZ```/``N$?Y'R`#U1\@`]5T`@"+
M<VI@^"(`@%(!``#0(<`DD>`#$ZIS^/^7`@``T.$#`*I"("61X`,3JCKX_Y?3
M@@R1@@)`^>$#%:H```#0`,`:D5_$`CEG^?^78`H`^<`"`+0!.(!2?_C_EP$$
M`!$_!`!Q!(A1>D$$`%2@``#P`,!'^>$G0/D"`$#Y(0`"ZP(`@-)!`P!4\U-!
MJ?5;0JGW&T#Y_7O%J,`#7]8`!$`YH/3_-*/__Q=@!D#Y$_[_EV`*`/D`_?^U
M````T`!`)9%-^/^7P((,D8(*0/D!!$#Y0`!`^2$`0/D_^O^7Q?__%\`"0/E8
M^/^7JO__%P+X_Y?6@@R1XP,`*@```-``X"61P8I`J2$`0/D[^/^7'R`#U1\@
M`]7]>[ZI_0,`D?-3`:GS`P"JN/O_EZS[_Y?T`P"J`OW_EQ\``'%D&D#Z@0``
M5/-30:G]>\*HP`-?UF`"0#F`__\T`0``T.`#%*HA(""1@@"`TJSW_Y?`_O\U
MX`,3JO-30:G]>\*H6/G_%P``````````_X,*T:$``/#B8P"1!>``D0C@`9'D
M`P*J_7L`J?T#`)$AP$?Y(P!`^>-/`?D#`(#2H0!`N81``)&CA$#X(0C`6H$`
M'_AA_&#39_QHT^<<>)(FW'C3(1P(4\8<<)+CX$.J(0`&JB$``ZJ!@!_X'P$%
MZP'^_U1%``B100!`^4(@`)%#!$#Y1!Q`^6,``<I!,$#Y(0`$RB$``\HC_%_3
M800!JB%\0))!/`#Y7P`%ZV'^_U0'*$"I)#./T@@D0:E$4*ORY9M!J2-TG=+B
M_%O3[/Q"TT(4!ZJ,>0>J(0$(RB/;K?(A``J*(0`)RJ4`!(LB0"*+0?U"TR%X
M"JI"``6+"Q!`^2U\0)*E`0C*Q@`$BT(`"PNE``>*I0`(RB$`#,I._%O33_Q"
MTZ4`"8O.%0*JI0`&BR$``HKB>0*JI0`."^:_0JDA``W*KOQ;TR$`"(O.%06J
ML/Q"T\8`!(OO`02+(0`&BX8!`LHA``X+C'U`DL8`!8K&``S*+OQ;T\8`#8O.
M%0&J#7H%JL8`#XO&``X+10`-RNX?0/E"?$"2I0`!BC#\0M.E``+*S@$$BZ4`
M#(O/_%O3#'H!JN\5!JJA`0S*I0`.B^XC0/FE``\+K7U`DB$`!HHA``W*S_Q"
MT^9Y!JHA``*+P@$$BZ[\6],A``*+K_Q"TX(!!LK.%06J+@`."T(`!8KE>06J
MC'U`DN&_1*E"``S*0@`-B\W]6].M%0ZJT'Q`DB$`!(M"``&+P0`%RDT`#0LA
M``Z*(0`0RL;]0M/B`02+SG@.JB$`#(NO_5O3IGQ`DB$``HOO%0VJH@`.RJ7]
M0M,O``\+I7@-JD(`#8KAMT6I0@`&RD(`$(OL_5O3C!4/JO#]0M,A``2+0@`!
MB\$!!<HA``^*SGU`DB$`#LI,``P+#WH/JJ(!!(LA``:+C?U;TR$``HNB``_*
M0@`,BJ5\0))"``7*K14,JD(`#HLM``T+\+M&J8;]0M/&>`RJH?U;TRP4#:KA
M`0;*(0`-BN]]0)(A``_*$`($BR$`!8M"`!"+L/U"TTP`#`L->@VJP@$$BR$`
M`HO"``W*0@`,BL9\0))"``;*COU;TT(`#XO.%0RJ\+]'J2X`#@N%_4+3I7@,
MJL']6],L%`ZJH0$%RB$`#HJM?4"2$`($BR$`#<I"`!"+T/U"TTP`#`L.>@ZJ
MX@$$BR$`!HLA``*+H@`.RD(`#(JE?$"20@`%RH_]6]-"``V+[Q4,JO"W2*DO
M``\+AOU"T\9X#*KA_5O3+!0/JL$!!LHA``^*SGU`DA`"!(LA``[*0@`0B_#]
M0M-,``P+#WH/JJ(!!(LA``6+(0`"B\(`#\I"``R*QGQ`DD(`!LJ-_5O30@`.
MBZT5#*KPNTFI+0`-"X7]0M.E>`RJH?U;TRP4#:KA`07*(0`-BN]]0)(0`@2+
M(0`/RD(`$(NP_4+33``,"PUZ#:K"`02+(0`&BR$``HNB``W*COU;TZ5\0))"
M``R*SA4,JD(`!<HN``X+0@`/BX;]0M/AOTJIS'@,JL;]6]/&%`ZJ(0`$B^0!
M!(M"``&+H0$,RB$`#HJM?4"2(0`-RL_]0M/2``(+[GD.JB$`!8M"0":+[U]`
M^2$`!(N$`0[*1?Y;TX0``DJE%!*JX@$#BX0`#8M-_D+3L``!"[)Y$JJ$``*+
MXF-`^2%`)8O%`1+*!OY;TZ4``4K&%!"J00`#BPW^0M.B0"R+SP`$"ZUY$*I"
M``&+X6=`^81`)HM&`@W*Y?U;T\0`!$JE%`^J)@`#BX%`+HNQ``(+(0`&B^S]
M0M-"0"6+YFM`^8]Y#ZJE`0_*)/Y;TX04$:JE``)*P@`#BR;^0M.0``$+T7@1
MJN9O0/DA0"2+Y`$1RJQ`,HN$``%*!?Y;TZ44$*J"`0*+P0`#BPS^0M.&0"V+
MK@`""Y!Y$*K!``&+YG-`^4)`)8LE`A#*Q/U;TZ(``DJ$%`ZJQ@`#BT)`+XO,
M_4+3C0`!"XYY#JI"``:+YG=`^2%`)(L$`@[*I?U;TX$``4JE%`VJQ@`#BR%`
M,8NO``(+(0`&BZS]0M-"0"6+YGM`^8UY#:K%`0W*Y/U;TX04#ZJE``)*P@`#
MB^;]0M.1``$+SW@/JN9_0/DA0"2+I`$/RJQ`,(N$``%*)?Y;TZ44$:J"`0*+
MP0`#BRS^0M.&0"Z+L``""XQY$:K!``&+YH-`^4)`)8OE`0S*!/Y;TZ(``DJ$
M%!"JQ@`#BT)`+8L-_D+3C@`!"T(`!HNF>1"J\(=`^2%`)(N$`0;*Q?U;TX$`
M`4JE%`ZJ$`(#BR%`+XNM``(+(0`0B\_]0M-"0"6+\(M`^>YY#JK%``[*I/U;
MTX04#:JE``)*`@(#B[#]0M./``$+#7H-JO"/0/DA0"2+Q`$-RJQ`+(N$``%*
MY?U;TZ44#ZJ&0":+`0(#BX(!`HOP_4+3K``""\$``8L&>@^J\)-`^4)`)8NE
M`0;*A/U;TZ(``DJ$%`RJ$`(#BT)`+HN._4+3CP`!"\QY#*I"`!"+\)=`^2%`
M)(O$``S*Y?U;TX$``4JE%`^J$`(#BR%`+8OM_4+3K@`""Z]Y#ZHA`!"+\)M`
M^4)`)8N%`0_*Q/U;TZ(``DJ$%`ZJ0D`FBP4"`XO0_4+3C0`!"T4`!8L">@ZJ
M\)]`^2%`)(OD`0+*IOU;TX0``4K&%`VJ`0(#BX1`+(NP_4+3A``!BP%Z#:K.
M``4+I4`FBT8``<K%``5*S/U;TZ5`+XO/_4+3C!4.JNYY#JKP/U2IC0$$"X1`
M+(NF_5O3QA0-JA`"`XNE`!"+,``.RLP`!0L0`@1*`D(BB^0!`XNP_4+3C_U;
MTPUZ#:KO%0RJ0@`$BZ5`)HODJT#Y0@`/"\8!#<K%``5*@P`#BX;]0M.A0"&+
M1/Q;T\QX#*J$%`*J(0`#BR$`!`NC`0RJY*]`^84!#0IC``**3_Q"TV,`!:J&
MFY?29N.Q\N)Y`JJ$``:+8T`NBR7\6],N_$+3I10!JF,`!(N$`0*J8P`%"X0`
M`8K!>0&JY3M6J4\`#`J$``^J;_Q"TX1`+8MM_%O3K14#JJ4`!HO.`0:+A``%
MBT4``:J$``T+I0`#BBT``@JE``VJC?Q;TZ5`+(OL>0.JI0`.BZ,5!*HM``RJ
MHP`#"^Z[0/FE`02*C0$!"H_\0M.E``VJS@$&BZ5`(HMM_%O3XGD$JJT5`ZJ$
M`0*JI0`.B^Z_0/FE``T+A``#BDT`#`J$``VJ;_Q"T\X!!HN$0"&+K?Q;T^%Y
M`ZJM%06JA``.BX0`#0M#``&J[<-`^2X``@IC``6*K_Q"TV,`#JKE>06JK0$&
MBV-`+(N._%O3+``%JLX5!*IC``V+[<=`^6,`#@N,`02*K@`!"HP!#JJ._$+3
M@D$BBZP!!HMM_%O3Q'D$JJT5`ZI"``R+0@`-"ZP`!*KMRT#YC@`%"HP!`XIO
M_$+3C`$.JN-Y`ZJM`0:+@4$ABT[\6].,``.JSA4"JB$`#8LA``X+C`$"BFX`
M!`J,`0ZJ3OQ"T\)Y`JJ%026+[;M9J2_\0M.L`0:++?Q;TZT5`:JE``R+;``"
MJJ4`#0N,`0&*30`#"HP!#:KA>0&JS@$&BX1!)(NM_%O33``!JJT5!:J$``Z+
M[M=`^80`#0N,`06*+0`""HP!#:JO_$+3S@$&BX-!(XN-_%O3['D%JJT5!*HE
M``RJ8P`.BZ4`!(KNVT#Y8P`-"XT!`0J/_$+3I0`-JN1Y!*K.`0:+HD`BBVW\
M6].%`02JK14#JD(`#HONWT#Y0@`-"Z4``XJ-``P*;_Q"TZ4`#:K.`0:+H4`A
MBTW\6]/E>0.JK14"JH,`!:HA``Z+3OQ"TR$`#0MC``**PGD"JJ\`!`KM.URI
M8P`/JFQ`+(LC_%O38Q0!JB_\0M.M`0:+C`$-BZT``JJ#`0,+K`$!BDT`!0KA
M>0&JC`$-JFW\6].$022+S`$&BX0`#(M,``&J+@`""HP!`XJ,`0ZJK14#JH5!
M)8N$``T+[S-=J6W\0M.M>0.JCOQ;T\X5!*KO`0:+HP`/BR4`#:IC``X+I0`$
MBJX!`0JE``ZJCOQ"T\1Y!*JB0"*+A0$&BVS\6].,%0.J0@`%BV[\0M.E`02J
M0@`,"Z4``XK#>0.JCP`-"NP[7JFE``^JI4`ABT'\6],A%`*J3_Q"TXP!!HNE
M``R+C``#JJ4``0N,`0**80`$"N)Y`JJ,`0&J4``#"H%!+8O-`0:+K/Q;TR$`
M#8N,%06J;0`"JN_[0/F.`0$+K0$%BBQ`+(NM`1"JT/U"TZ1!)(OM`0:+K_Q"
MT\;]6]/&%`ZJA``-B^UY!:K2``0+[_]`^4$`#<HA``Q*Q3J8TD5,N?(A0".+
M[`$%BT/^6],.>@ZJ8Q02JB$`#(N$0":+[`-!^7$``0NF`0[*(4`CB\0`!$J&
M`06+@D`BBTS^0M,D_EO3DGD2JH04$:I"``:+[`=!^9```@O#`1+*)OY"TV,`
M`4J!`06+;$`MBP/^6]/1>!&JC`$!BV,4$*I"0"2+Y@M!^6\`#`M$`A'*@T$C
MBX0``DKA_5O3P@`%BX9`+HL$_D+3Q@`"BY!X$*HA%`^JY`]!^2X`!@LB`A#*
M[/U"TT(``TJ#``6+1$`RB\+]6]./>0^JA``#BT(4#JK!0"&+XQ-!^4T`!`L&
M`@_*S/U"T\$``4IF``6+(T`QBZ']6]..>0ZJ8P`&BR$4#:KL`0[*YA=!^3(`
M`PN"0"*+84`ABX(!`DK$``6+3$`PBZ;]0M-"_EO3S7@-JH0!!(M"%!*JYAM!
M^5$`!`O#`0W*3/Y"TV$``4K#``6+)D`OBR'^6]/#``.+C'D2JB$4$:J"0"*+
MYA]!^3```PND`0S*84`ABX(``DK&``6+1$`NBR[^0M,"_EO3A``&BT(4$*K&
M>1&J[B-!^4\`!`N#`0;*@D`BBV$``4K.`06+(T`MBPW^0M/A_5O3L'D0JF,`
M#HLA%`^J[B=!^2T``PO$`!#*84`ABX(``DK$`06+3$`LB^[]0M.B_5O3SWD/
MJH0!!(M"%`VJ["M!^4X`!`L#`@_*@D`BBV$``4J#`06+)D`FBZS]0M/!_5O3
MPP`#BR$4#JJ&>0VJ["]!^2T``POD`0;*84`ABX(``DJ,`06+1$`PB]#]0M.B
M_5O3#GH.JH0`#(M"%`VJ[#-!^5$`!`O#``[*@D`BBV$``4J,`06+(T`OBZ_]
M0M,A_EO3[7D-JF,`#(LA%!&J[#=!^3```PO$`0W*+_Y"TX(``DJ$`06+3$`F
MBP+^6].&`02+0A00JNQY$:IA0"&+Y#M!^4\`!@NC`0S*PD`BBV$``4J#``6+
M)$`NBP[^0M/A_5O3A``#BR$4#ZK#>1"J\#]!^2X`!`N&`0/*@4`AB\(``DH0
M`@6+1D`MB^W]0M/"_5O3KWD/JD(4#JK&`!"+[4-!^5``!@MD``_*PD`BBX0`
M`4JA`06+C$`LB\W]0M,$_EO3C`$!BZYY#JJ$%!"JX4=!^9$`#`OF`0[*YT`O
MB\8``DHB``6+PT`CBR'^6]-C``*+(101JF,``0L!_D+3[4M!^2%X$*J&022+
MP@$!RF3\6].L``#01@`&2H04`ZJE`06+(OY"TX0`!HNE``>+AL%'^4)X$:HA
M``D+RP$+"V,`"@N$``4+2``("P0,`*D(!`&I"Q``^>!/0?G!`$#Y```!ZP$`
M@-*!``!4_7M`J?^#"I'``U_6O//_E_U[OZD`$(#2_0,`D5CT_Y<?&`#Y)F"$
MTB5QE=+$GYO2PXZ*T@(^G-*FZ*SRI?F]\D07L_)#!J+R0GJX\@84`*D$#`&I
M`GP"J1]X`+G]>\&HP`-?UA\@`]4?(`/5_7N\J4)\0)/]`P"1\U,!J13@`)'S
M`P&J]5L"J?4#`*KV`P*J]V,#J06,0JD`>$"YI`P""[\`!.MCE(.:8G1"BZ2*
M`JG@`@`T%PB`4O<"`$O?`A=K@,(@B]?2EQKX?D"3X@,8JH/S_Y>@>D"YX`(`
M"Z!Z`+D?``%QP```5/-30:GU6T*I]V-#J?U[Q*C``U_6U@(72W,"&(O@`Q6J
MH?O_E]_^`''M`P!4U@(!4=A^!E,7!P`1]VIZTW<"%XL?(`/58`9`J8`&`*ES
M`@&18@Y]J8(.`:G@`Q6J8@Y^J8(.`JEB#G^I@@X#J8[[_Y=_`A?K@?[_5-8:
M&$OA`Q>JPGY`D^`#%*I;\_^7MGH`N?-30:GU6T*I]V-#J?U[Q*C``U_6]P,3
MJO7__Q<?(`/5'R`#U?U[O*G]`P"1\U,!J?,#`:KT`P"J]5L"J77B`)'A#X`2
M]QL`^6`60/EV*D"Y=S)`N0`@`U/6"L!:`@0`$?<*P%JARB`XH,(BBU_@`'&-
M"0!4`0B`4B(``DL!`(!20GQ`DV3S_Y?@`Q.J8OO_EW_^`ZE__@2I?_X%J7\V
M`/EW6@XIX`,3JEO[_Y=A`D#YX`,3JB'\6-.!`@`Y80)`^2'\4-.!!@`Y80)`
M^2'\2-.!"@`Y80)`^8$.`#EA!D#Y(?Q8TX$2`#EA!D#Y(?Q0TX$6`#EA!D#Y
M(?Q(TX$:`#EA!D#Y@1X`.6$*0/DA_%C3@2(`.6$*0/DA_%#3@28`.6$*0/DA
M_$C3@2H`.6$*0/F!+@`Y80Y`^2'\6-.!,@`Y80Y`^2'\4-.!-@`Y80Y`^2'\
M2-.!.@`Y80Y`^8$^`#EA$D#Y(?Q8TX%"`#EA$D#Y(?Q0TX%&`#EA$D#Y(?Q(
MTX%*`#EA$D#Y@4X`.?-30:GU6T*I]QM`^?U[Q*C.\O\7`0>`4B(``DL!`(!2
M0GQ`DQGS_Y>[__\7````````````````H```T`!`"Y$!($$Y00,`-:$``+`B
M`(!2`B`!.2"D1_F@`0"T_7N_J:```-#]`P"1``A!^9?R_Y>@``"P`-1'^6`!
M`+3]>\&H(```D`#@(Y%(\_\7H```L`#41_G```"T(```D`#@(Y%"\_\7_7O!
MJ,`#7];``U_6``````````"@``#0`4`+D0)`2SE"`0`UH@``L",`@%(#0`LY
M0+1'^:```+0A(`"1(```D`#@(Y'(\O\7P`-?U@``````````_7NZJ:,``+#]
M`P"18\!'^?-3`:GU6P*IXH<#J>+C`)'A`P&1X$\`N>`S`9%D`$#YY"\`^00`
M@-+J\O^7H```L*(``+``X$?Y0LQ'^>$#`JKT\O^7H```L`"P1_D``$`Y@`D`
M-$'0.]6S``#0H```L`"X1_D?(`/5'R`#U2-H8/CB3T"Y80A2.4`0`!%4#``1
M(00`,F$($CD`?'V3P?+_E^,#`*JA``"P8H(,D>8C0/D```"0),A'^0`@)Y'E
M3T"Y`0``D,<`0/DA`">1A`!`^6<$`*E#!`#Y9``!J;\$`'$M"0!4(0"`TB`,
M`!'$>&'X(00`D638(/B_``%K;/__5*4,`!%U@@R1?]@E^.'__[#B`Q0J(9`L
MD00`@-*@#D#YU/+_ER`%`#1U@@R1]E,!D:`.0/EO\O^7]`,`*N$#%JH```"0
M`*`<D:KS_Y=`!`"T<X(,D6`.0/E2\O^7M?+_EZ```+``P$?YX2]`^0(`0/DA
M``+K`@"`TN$$`%3@`Q0J\U-!J?5;0JG]>\:HP`-?UFCR_Y>S``#08H(,D4`,
M`/E@`P"T+_+_ET'0.]6@``"P`+A'^1\@`]4?(`/5(&A@^!\8)#FJ__\7H`Y`
M^<WR_Y?6__\7H`I`^6```+11^O^7W/__%^$#%JH```"0`,`:D8#S_Y>@"@#Y
MP/K_M$GZ_Y?4__\7A0"`4K___Q<@`(!2Y/'_ESOR_Y=P<U]S=')I;F=S(&UI
M<W-I;F<*```````O=&UP+P```"X`````````4$%27U1-4$1)4@```````%1-
M4$1)4@``5$5-4$1)4@!414U0`````%1-4```````55-%4@````!54T523D%-
M10``````````)7,O)7,````O<')O8R]C=7)P<F]C+V5X90````````!$>6YA
M3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(``````$EN=&5R;F%L<SHZ4$%2.CI"
M3T]4`````%!!4E]414U0``````````!005)?4%)/1TY!344`````.@``````
M```O`````````"5S)7,E<P``4$523#5,24(``````````%!%4DQ,24(`4$52
M3#5/4%0``````````%!%4DQ)3P``4$%27TE.251)04Q)6D5$`%!!4E]34$%7
M3D5$``````!005)?0TQ%04X`````````4$%27T1%0E5'`````````%!!4E]#
M04-(10````````!005)?1TQ/0D%,7T1%0E5'``````````!005)?1TQ/0D%,
M7U1-4$1)4@````````!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!
M3@``````````,0````````!L<V5E:R!F86EL960`````<F5A9"!F86EL960`
M`````$Q$7TQ)0E)!4EE?4$%42`!365-414T``"4P,G@`````<&%R+0`````E
M<R5S)7,E<P``````````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER
M96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@```````"5S.B!P<FEV871E
M('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A9F4@*'!L96%S92!R96UO=F4@:70@
M86YD(')E=')Y('EO=7(@;W!E<F%T:6]N*0H```````!0051(`````'!A<FP`
M````+G!A<@````!S:&]R="!R96%D````````)7,E<V-A8VAE+25S)7,``"5S
M)7-T96UP+25U)7,````E<R5S=&5M<"TE=2TE=25S```````````8````````
M`'!E<FP`````,`````````!005(Z.E!A8VME<CHZ5D524TE/3@`````Q+C`U
M.0```%5N86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y```````````E
M<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@
M9F%I;&5D("AE<G)N;STE:2D*```````````M90```````"TM````````979A
M;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"FEF(#`[
M(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`IP86-K86=E(%]?<&%R
M7W!L.PIM>2`H)%!!4E]-04=)0RP@)$9)3$5?;V9F<V5T7W-I>F4L("1C86-H
M95]N86UE7W-I>F4I.PI"14=)3B!["B1005)?34%'24,@/2`B7&Y005(N<&U<
M;B(["B1&24Q%7V]F9G-E=%]S:7IE(#T@-#L@("`C('!A8VLH(DXB*0HD8V%C
M:&5?;F%M95]S:7IE(#T@-#`["B102UI)4%]-04=)0R`](")02UPP,#-<,#`T
M(CL*?0IS=6(@9FEN9%]P87)?;6%G:6,*>PIM>2`H)&9H*2`]($!?.PIM>2`D
M8VAU;FM?<VEZ92`](#8T("H@,3`R-#L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M
M<R`D9F@["FUY("1P;W,@/2`H)'-I>F4M,2D@+2`H)'-I>F4M,2D@)2`D8VAU
M;FM?<VEZ93L@("`@("`C($Y/5$4Z("1P;W,@:7,@82!M=6QT:7!L92!O9B`D
M8VAU;FM?<VEZ90IW:&EL92`H)'!O<R`^/2`P*2!["G-E96L@)&9H+"`D<&]S
M+"`P.PIR96%D("1F:"P@)&)U9BP@)&-H=6YK7W-I>F4@*R!L96YG=&@H)%!!
M4E]-04=)0RD["FEF("@H;7D@)&D@/2!R:6YD97@H)&)U9BP@)%!!4E]-04=)
M0RDI(#X](#`I('L*<F5T=7)N("1P;W,@*R`D:3L*?0HD<&]S("T]("1C:'5N
M:U]S:7IE.PI]"G)E='5R;B`M,3L*?0IM>2`H)'!A<E]T96UP+"`D<')O9VYA
M;64L($!T;7!F:6QE+"`E36]D=6QE0V%C:&4I.PI%3D0@>R!I9B`H)$5.5GM0
M05)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE
M.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@
M1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ<5M2
M96UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(ETI.PI&:6QE.CI&:6YD.CIF
M:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A
M<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H+60@)'!A<E]T96UP("8F
M("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE.CI496UP
M*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S96YA
M;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.
M2R`]/B`P+`HI.PIM>2`D9FEL96YA;64@/2`D=&UP+3YF:6QE;F%M93L*<')I
M;G0@)'1M<"`\/"(N+BXB.PIX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D
M;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=
M.R!T:&5N"F)R96%K"F9I"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE
M"G)M("<D9FEL96YA;64G"BXN+@IC;&]S92`D=&UP.PIC:&UO9"`P-S`P+"`D
M9FEL96YA;64["FUY("1C;60@/2`B)&9I;&5N86UE(#XO9&5V+VYU;&P@,CXF
M,2`F(CL*<WES=&5M*"1C;60I.PIO=71S*'%Q6U-P87=N960@8F%C:V=R;W5N
M9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@)&9I;&5N86UE72D["GT*
M?2!]"D)%1TE.('L*26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D
M("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*979A;"!["E]P87)?:6YI=%]E;G8H
M*3L*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)7-Y<R`]("@*
M<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL
M"E]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN
M*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-
M4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*
M;W5T<RAQ<5M<)'!R;V=N86UE(#T@(B1P<F]G;F%M92)=*3L*7W-E=%]P87)?
M=&5M<"@I.PIO=71S*'%Q6UPD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]4
M14U0?2)=*3L*;7D@*"1S=&%R=%]P;W,L("1S=&%R=%]O9E]&24Q%7W-E8W1I
M;VXI.PI-04=)0SH@>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*
M=6YL97-S("AO<&5N(%]&2"P@)SPZ<F%W)RP@)'!R;V=N86UE*2!["F]U=',H
M<7%;0V%N)W0@<F5A9"!F<F]M(&9I;&4@(B1P<F]G;F%M92)=*3L@(",@9&]N
M)W0@=7-E("0A(&AE<F4@87,@:70@<F5Q=6ER97,@17)R;F\N<&T*;&%S="!-
M04=)0SL*?0IM>2`D;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G:6,H*E]&2"D[
M"FEF("@D;6%G:6-?<&]S(#P@,"D@>PIO=71S*'%Q6T-A;B=T(&9I;F0@;6%G
M:6,@<W1R:6YG("(D4$%27TU!1TE#(B!I;B!F:6QE("(D<')O9VYA;64B72D[
M"FQA<W0@34%'24,["GT*;W5T<R@B1F]U;F0@4$%2(&UA9VEC(&%T('!O<VET
M:6]N("1M86=I8U]P;W,B*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,
M15]O9F9S971?<VEZ92`M(&QE;F=T:"@B7#!#04-(12(I+"`P.PIR96%D(%]&
M2"P@)&)U9BP@;&5N9W1H*")<,$-!0TA%(BD["FEF("@D8G5F(&YE(")<,$-!
M0TA%(B`F)B`D8G5F(&YE(")<,$-,14%.(BD@>PIO=71S*").;R!C86-H92!M
M87)K97(@9F]U;F0B*3L*;&%S="!-04=)0SL*?0IO=71S*'%Q6T-A8VAE(&UA
M<FME<B`B)&)U9B(@9F]U;F1=*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D
M1DE,15]O9F9S971?<VEZ92P@,#L*<F5A9"!?1D@L("1B=68L("1&24Q%7V]F
M9G-E=%]S:7IE.PIM>2`D;V9F<V5T(#T@=6YP86-K*").(BP@)&)U9BD["F]U
M=',H(D]F9G-E="!F<F]M('-T87)T(&]F($9)3$5S(&ES("1O9F9S970B*3L*
M<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92`M("1O
M9F9S970L(#`["B1S=&%R=%]O9E]&24Q%7W-E8W1I;VX@/2!T96QL(%]&2#L*
M;7D@)7)E<75I<F5?;&ES=#L*<F5A9"!?1D@L("1B=68L(#0[("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(R!R96%D('1H92!F:7)S="`B1DE,12(*=VAI
M;&4@*"1B=68@97$@(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D
M(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]
M("1B=68["F]U=',H<7%;56YP86-K:6YG($9)3$4@(B1F=6QL;F%M92(N+BY=
M*3L*;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\
M?"`I(#\@)#$@.B!U;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U
M9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@
M-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F
M:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI
M('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1C<F,D97AT(BP@)&)U9BP@
M,#<U-2D["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F
M:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@
M)&9U;&QN86UE.PI]"F5L<V4@>PHD36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]
M('L*8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M
M92P*?3L*)')E<75I<F5?;&ES='LD9G5L;&YA;65]*RL["GT*<F5A9"!?1D@L
M("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M
M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L
M93L*;7D@)&EN9F\@/2`D36]D=6QE0V%C:&5[)&UO9'5L97T["G)E='5R;B!U
M;FQE<W,@)&EN9F\["F1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5].PHD
M24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&EN9F\O)&UO9'5L92(["FEF("@D
M14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2![
M"FUY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@(D-A;B=T
M(&-R96%T92!T96UP(&9I;&4Z("0A(CL*)&9H+3YB:6YM;V1E*"D["B1F:"T^
M<')I;G0H)&EN9F\M/GMB=69]*3L*)&9H+3YS965K*#`L(#`I.PIR971U<FX@
M)&9H.PI]"F5L<V4@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&EN9F\M
M/GMC<F-]+G!M(BP@)&EN9F\M/GMB=69]*3L*)&EN9F\M/GMF:6QE?2`]("1F
M:6QE;F%M93L*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1F:6QE;F%M92!O<B!D
M:64@<7%;0V%N)W0@<F5A9"`B)&9I;&5N86UE(CH@)"%=.PIR971U<FX@)&9H
M.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;B=T(&9I;F0@;6]D
M=6QE("1M;V1U;&4A(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97(["G)E
M<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER
M92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D
M97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M92`]
M("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D24Y#
M>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF("@D
M9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M93L*
M?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I
M=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES='LD
M9FEL96YA;65].PI]"FEF("@D8G5F(&YE("102UI)4%]-04=)0RD@>PIO=71S
M*'%Q6TYO('II<"!F;W5N9"!A9G1E<B!&24Q%('-E8W1I;VX@:6X@9FEL92`B
M)'!R;V=N86UE(ETI.PIL87-T($U!1TE#(#L*?0HD<W1A<G1?<&]S(#T@*'1E
M;&P@7T9(*2`M(#0[("`@("`@("`@("`@("`@(",@<W1A<G0@;V8@>FEP"GT*
M;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C
M:&5?;F%M92D["F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET
M:7IE("A2155312!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0II9B`H(21S
M=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S
M:&EF="DI('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II
M("`@:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R
M"G8@("!V97)I9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@
M)RTM<F5U<V4G*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5]
M(#T@<VAI9G0@0$%21U8["GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H879I
M;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@
M/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q
M(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@
M97$@)TTG*2!["F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@
M>PIU;G-H:69T($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@
M>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@
M)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG
M.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H
M)#$@97$@)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@<7%;
M0V%N)W0@;W!E;B!L;V<@9FEL92`B)#(B.B`D(5T["GT*96QS:68@*"0Q(&5Q
M("=4)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@
M*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?
M5$5-4"=].PII;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2
M.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ
M)&-M9")]*"1?*2!F;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L
M($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&
M:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(
M03L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F
M:6YE9"`D<&%R*2!["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D<&%R(&]R(&1I
M92!Q<5M#86XG="!F:6YD('!A<B!F:6QE("(D<&%R(CH@)"%=.PIB;&5S<R@D
M9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@
M)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV
M93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP
M(&%R8VAI=F4@(B1P87(B73L*?0IM>2`E;65T85]P87(@/2!D;R!["FEF("@D
M>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I
M*2!["B1M971A(#U^(',O+BI><&%R.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ
M+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT["FEF
M("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D<&@L("<\.G)A=R<L("1P87(@
M;W(@9&EE('%Q6T-A;B=T(')E860@<&%R(&9I;&4@(B1P87(B.B`D(5T["FUY
M("1B=68["G)E860@)'!H+"`D8G5F+"`T.PID:64@<7%;(B1P87(B(&ES(&YO
M="!A('!A<B!F:6QE72!U;FQE<W,@)&)U9B!E<2`D4$M:25!?34%'24,["F-L
M;W-E("1P:#L*?0I#<F5A=&50871H*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I
M;&4M/FYE=R@*)&]U="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE
M.CI/7U)$5U(H*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@
M9&EE('%Q6T-A;B=T(&-R96%T92!F:6QE("(D;W5T(CH@)"%=.PHD9F@M/F)I
M;FUO9&4H*3L*<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D97(["FEF("AD969I
M;F5D("1S=&%R=%]O9E]&24Q%7W-E8W1I;VXI('L*<F5A9"!?1D@L("1L;V%D
M97(L("1S=&%R=%]O9E]&24Q%7W-E8W1I;VX["GT@96QS92!["FQO8V%L("0O
M(#T@=6YD968["B1L;V%D97(@/2`\7T9(/CL*?0II9B`H(21%3E9[4$%27U9%
M4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q
M=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13
M=')I<"T^87!P;'DH7"1L;V%D97(L("0P*3L*?0HD9F@M/G!R:6YT*"1L;V%D
M97(I"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG(&QO861E<B!T;R`B)&]U="(Z
M("0A73L*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z
M.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I
M<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R
M97`@>PHH)&)U;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#
M;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP
M<FEV;&EB97AP?2D["GT@0$E.0SL*<WPO*WPO?&<L('-\+R1\?"!F;W)E86-H
M($!I;F,["FUY("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO861E
M<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X
M="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L@("`@("`@("`C(%A86"!L
M:6)?97AT('9S(&1L97AT(#\*;7D@)7=R:71T96X["F9O<F5A8V@@;7D@)&ME
M>2`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&9I;&4L("1N86UE*3L*:68@
M*&1E9FEN960H;7D@)&9C(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD:V5Y
M?2DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)&9C*3L*?0IE;'-E('L*
M9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D:V5Y(#U^(&U\7EQ1)&1I
M<EQ%+R@N*BDD?&DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)#$I.PIL
M87-T.PI]"FEF("@D:V5Y(#U^(&U\7B]L;V%D97(O6UXO72LO*"XJ*21\*2![
M"FEF("AM>2`D<F5F(#T@)$UO9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L("1N
M86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*:68@*"UF("(D9&ER+R0Q(BD@
M>PHH)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]
M"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE.PIN97AT(&EF("1W<FET
M=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]
M?B`O7"Y<421L:6)?97AT7$4D+VD["F]U=',H<W!R:6YT9BAQ<5M086-K:6YG
M($9)3$4@(B5S(BXN+ETL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D
M9FEL92DI.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI('L*)&-O;G1E
M;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92!["FQO8V%L("0O(#T@=6YD968[
M"F]P96X@;7D@)'1H+"`G/#IR87<G+"`D9FEL92!O<B!D:64@<7%;0V%N)W0@
M<F5A9"`B)&9I;&4B.B`D(5T["B1C;VYT96YT(#T@/"1T:#X["F-L;W-E("1T
M:#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&-O;G1E;G0L("(\
M96UB961D960^+R1N86UE(BD*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@
M)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T
M8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE
M*3L*?0HD9F@M/G!R:6YT*")&24Q%(BP*<&%C:R@G3B<L(&QE;F=T:"@D;F%M
M92D@*R`Y*2P*<W!R:6YT9B@B)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M
M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64I+`IP86-K*"=.)RP@;&5N9W1H
M*"1C;VYT96YT*2DL"B1C;VYT96YT*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN
M9R!E;6)E9&1E9"!&24Q%('1O("(D;W5T(CH@)"%=.PIO=71S*'%Q6U=R:71T
M96X@87,@(B1N86UE(ETI.PI]"GT*:68@*"1Z:7`I('L*)'II<"T^=W)I=&54
M;T9I;&5(86YD;&4H)&9H*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+"F]R(&1I
M92!Q<5M%<G)O<B!W<FET:6YG('II<"!P87)T(&]F("(D;W5T(ET["GT*:68@
M*"1M971A7W!A<GMC;&5A;GTI('L*)&9H+3YP<FEN="@B7#!#3$5!3B(I.PI]
M"F5L<V4@>PII9B`H(61E9FEN960@)&-A8VAE7VYA;64I('L*;7D@)&-T>"`]
M($1I9V5S=#HZ4TA!+3YN97<H,2D["G-E96L@)&9H+"`P+"`P.PHD8W1X+3YA
M9&1F:6QE*"1F:"D["G-E96L@)&9H+"`P+"`R.PHD8V%C:&5?;F%M92`]("1C
M='@M/FAE>&1I9V5S=#L*?0HD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?
M;F%M92P@,"P@)&-A8VAE7VYA;65?<VEZ93L*)&-A8VAE7VYA;64@+CT@(EPP
M(B!X("@D8V%C:&5?;F%M95]S:7IE("T@;&5N9W1H("1C86-H95]N86UE*3L*
M)&9H+3YP<FEN="@D8V%C:&5?;F%M92P*(EPP0T%#2$4B*3L*?0IM>2`D;V9F
M<V5T(#T@)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D97(I.PHD9F@M/G!R:6YT
M*'!A8VLH)TXG+"`D;V9F<V5T*2P*)%!!4E]-04=)0RD["B1F:"T^8VQO<V4@
M;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@=')A:6QE<B!O9B`B)&]U="(Z("0A
M73L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL97-S(&1E
M9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!
M4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E<75I<F4@
M1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)&9H(#T@
M24\Z.D9I;&4M/FYE=SL@("`@("`@("`@("`@("`@("`@("`@("`@("`@(",@
M07)C:&EV93HZ6FEP(&]P97)A=&5S(&]N(&%N($E/.CI(86YD;&4*)&9H+3YF
M9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE('%Q6V9D;W!E;B@I(&9A
M:6QE9#H@)"%=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@M<R!?1D@I
M.PIM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@D>FEP+3YR96%D1G)O
M;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ
M05I?3TLH*2D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@
M(B1P<F]G;F%M92)=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@V-"`J
M(#$P,C0I.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#
M86-H97LD<')O9VYA;65](#T@)'II<#L*;W5T<R@B17AT<F%C=&EN9R!Z:7`N
M+BXB*3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@
M8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z
M:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD[
M"FUY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N
M;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG
M.CI#;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A
M8W1?;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T
M9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D
M9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ
M92@I*2!["F]U=',H<7%;4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@
M:70@86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B72D["GT@96QS92![
M"F]U=',H<7%;17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?
M;F%M92(N+BY=*3L**"1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S
M=%]N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%
M<G)O<B!E>'1R86-T:6YG('II<"!M96UB97(@=&\@(B1D97-T7VYA;64B73L*
M8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]
M"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE
M(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=
M(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M
M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6
M>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6
M*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER
M92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I
M(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI
M.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T
M:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R
M"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E
M($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0[
M"G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P
M.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E
M($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&
M8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,[
M"G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/
M.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z
M.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ
M4TA!.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E
M(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E
M<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R
M:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@
M5VEN,S(@?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@
M>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q
M=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER
M92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E
M<75I<F4@=71F."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN
M960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI
M+RD@>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A
M=&@@*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-
M4$1)4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN
M97AT('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@
M)'!A=&@["FUY("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED
M*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE
M9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ
M3&]G:6Y.86UE.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA
M;64@/2`D<'=U:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!
M345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<["GT*;7D@)'-T;7!D:7(@
M/2`B)'!A=&@D<WES>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N
M86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34["FUY("1C86-H95]D:7(["FEF
M("@D14Y6>U!!4E]#3$5!3GTI('L*)&-A8VAE7V1I<B`](")T96UP+20D(CL*
M?0IE;'-E('L*;W!E;B!M>2`D9F@L("(\.G)A=R(L("1P<F]G;F%M92!O<B!D
M:64@<7%;0V%N)W0@<F5A9"`B)'!R;V=N86UE(CH@)"%=.PII9B`H*&UY("1M
M86=I8U]P;W,@/2!F:6YD7W!A<E]M86=I8R@D9F@I*2`^/2`P*2!["G-E96L@
M)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG=&@H
M(EPP0T%#2$4B*2P@,#L*;7D@)&)U9CL*<F5A9"`D9F@L("1B=68L(&QE;F=T
M:"@B7#!#04-(12(I.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D
M9F@L("1M86=I8U]P;W,*+2`D1DE,15]O9F9S971?<VEZ90HM(&QE;F=T:"@B
M7#!#04-(12(I"BT@)&-A8VAE7VYA;65?<VEZ92P@,#L*<F5A9"`D9F@L("1B
M=68L("1C86-H95]N86UE7W-I>F4["B1B=68@/7X@<R]<,"\O9SL*)&-A8VAE
M7V1I<B`](")C86-H92TD8G5F(CL*?0I]"F-L;W-E("1F:#L*?0II9B`H(21C
M86-H95]D:7(I('L*)&-A8VAE7V1I<B`](")T96UP+20D(CL*)$5.5GM005)?
M0TQ%04Y](#T@,3L*?0HD<W1M<&1I<B`N/2`B)'-Y<WM?9&5L:6U])&-A8VAE
M7V1I<B(["FUK9&ER("1S=&UP9&ER+"`P-S4U.PHD14Y6>U!!4E]414U0?2`]
M("1S=&UP9&ER.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%2
M7U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]S
M879E7V%S('L*;7D@*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]($!?.PIM
M>2`D9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S("@M92`D
M9G5L;&YA;64I('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD)"(["FUY
M("1F:#L**&]P96X@)&9H+"`G/CIR87<G+"`D=&5M<&YA;64I"B8F("AP<FEN
M="`D9F@@)&-O;G1E;G1S*0HF)B`H8VQO<V4@)&9H*0IO<B!D:64@<7%;17)R
M;W(@=W)I=&EN9R`B)'1E;7!N86UE(CH@)"%=.PIC:&UO9"`D;6]D92P@)'1E
M;7!N86UE(&EF(&1E9FEN960@)&UO9&4["G)E;F%M92@D=&5M<&YA;64L("1F
M=6QL;F%M92D@;W(@=6YL:6YK*"1T96UP;F%M92D["GT*<F5T=7)N("1F=6QL
M;F%M93L*?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[
M4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI
M+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H
M)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?
M5$5-4'TI(#X](#`I('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@
M<FEN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A
M)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?
M9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA
M;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921S
M>7-[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D<WES>U]E>&5].PIR971U<FX[
M"GT*?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421S>7-[<&%T:%]S97!]
M7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%
M35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D
M<WES>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1S>7-[7V1E
M;&EM?21P<F]G;F%M921S>7-[7V5X97TB*2P@;&%S="D*:68@+7,@(B1D:7(D
M<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5](CL**"@D<')O9VYA;64@
M/2`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B
M)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G
M;F%M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T[
M"FEF("AI;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/"`P*2!["B1P
M<F]G;F%M92`]("(N)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D
M(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H
M*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@
M8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_
M7%$D<WES>U]D96QI;7U<12DO)'!W9"1S>7-[7V1E;&EM?2\["B1%3E9[4$%2
M7U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B![
M"FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N
M.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H
M<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12`I
M("D@>PID96QE=&4@)$5.5GLB4$%27R1?(GT["GT*9F]R("AQ=R\@5$U01$E2
M(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6>R)005)?)%\B?2`]("1%3E9[
M(E!!4E]'3$]"04Q?)%\B?2!I9B!E>&ES=',@)$5.5GLB4$%27T=,3T)!3%\D
M7R)].PI]"FEF("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?
M0TQ%04Y].PI]"GT*<W5B(&]U=',@>PIR971U<FX@:68@)'%U:65T.PII9B`H
M)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B(["GT*96QS92!["G!R:6YT
M(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP
M=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD
M7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET
M96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA
M9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I
M;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@<7%;<&%R+G!L
M.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H
M(&9I;&4@;W(@9&ER96-T;W)Y7&Y="G5N;&5S<R`M92`D<')O9VYA;64["F1O
M("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)
M5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI].PHD.CI?7T524D]2(#T@
M)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO
M7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?
M7T524D]2.PHQ.PI?7T5.1%]?"@!P97)L>'-I+F,``````````$-!0TA%```!
M&P,[!`$``!\````XBO__'`$``)B*__](`0``_(K__W0!``!HC/__X`$``%R-
M__](`@``V([__Z@"``!LC___T`(``%B0__\$`P``7)'__SP#``",D___D`,`
M`,R3__^P`P``*)3__]0#```XE/__Z`,``%R6__](!```B);__VP$``#XEO__
MH`0``+R;___<!```+)S___P$``#(G/__&`4``#B>__^D!0``6)[__\0%``!\
MG___``8``$BE__]P!@``F*?__Z0&```(J/__"`<``(RX__\L!P``Z+C__TP'
M```8NO__D`<``+B[__^T`0``.+S__Z`!``!XO/__U`8````````0````````
M``%Z4@`$>!X!&PP?`"@````8````%(G__UP`````00XPG0:>!425`D64`Y,$
M2M330M[=U0X`````*````$0```!(B?__9`````!!#C"=!IX%0I,$E`-"E0)2
M"M[=U=/4#@!!"P`H````<````(")__]H`0```$$.0)T(G@="E`63!D&6`Y4$
M09<"`````````!````"<````D+K__S@`````````*````+````#\N?__>```
M``!*#A"=`IX!2-[=#@!)#A"=`IX!0=[=#@````!D````W````("*___T````
M`$$.0)T(G@="DP:4!4*8`9<"1I8#E016UM5!V-=#WMW3U`X`00Y`DP:4!94$
ME@.7`I@!G0B>!T_6U4'8UT'>W=/4#@!!#D"3!I0%G0B>!T*7`I@!0MC7`%P`
M``!$`0``#(O__W@!````00[@`9T<GAM(E!F3&D34TTC>W0X`00[@`9,:E!F=
M')X;1)@5EQ9$EA>5&'`*U--!UM5!V-=!"TG3U-76U]A!E!F3&D&6%Y4809@5
MEQ8``"0```"D`0``*(S__Y0`````00[``9T8GA=$DQ96"M[=TPX`00L````P
M````S`$``)2,___L`````$$.L`A$G88!GH4!0Y.$`6(*W=[3#@!!"TX*W=[3
M#@!!"P``-``````"``!,C?__!`$```!!#L`(0YV(`9Z'`4.3A@&4A0%"E80!
MEH,!=`K=WM76T]0.`$$+``!0````.`(``!B.__\P`@```$$.8)T,G@M#DPJ4
M"4R5")8'EP:8!0)`"M[=U]C5UM/4#@!!"TF:`YD$7PK:V4$+2=G:0ID$F@-#
MV=I!F@.9!$+:V0`<````C`(``/2/__]``````$$.$)T"G@%(WMT.`````"``
M``"L`@``%)#__UP`````00X@G02>`T.3`D[>W=,.`````!````#0`@``3)#_
M_P@`````````7````.0"``!(D/__)`(```!!#H`*0IV@`9Z?`4.3G@&4G0%#
ME9P!EIL!7`K=WM76T]0.`$$+2)B9`9>:`469F`%W"MC70=E!"U4*V-=!V4$+
M0]?8V4&8F0&7F@%!F9@!(````$0#```,DO__+`````!!#B"=!)X#0Y,"1M[=
MTPX`````,````&@#```4DO__;`````!"#B"=!)X#0I,"2@K>W=,.`$$+0PK>
MW=,.`$(+0][=TPX``#@```"<`P``4)+__\0$````00Y@G0R>"T25")8'0I,*
ME`E%EP:8!9D$`QH!"M[=V=?8U=;3U`X`00L``!P```#8`P``V);__W``````
M00X@G02>`U<*WMT.`$$+&````/@#```HE___G`````!!#J`"G22>(P```(@`
M```4!```J)?__VP!````00Y00@[0@`1$G8I`GHE`0Y.(0)2'0$V6A4"5AD!$
MF(-`EX1`8M;50MC72MW>T]1!#H"`!$$.`$$.T(`$DXA`E(=`E89`EH5`EX1`
MF(-`G8I`GHE`1M;50=C70I6&0):%0)>$0)B#0$/5UM?809:%0)6&0$&8@T"7
MA$``'````*`$``",F/__(`````!!#A"=`IX!1M[=#@`````X````P`0``(R8
M__\D`0```$$.0)T(G@=&DP:4!94$E@-8"M[=U=;3U`X`00M-"M[=U=;3U`X`
M00L```!L````_`0``'29___$!0```$$.D`.=,IXQ2),PE"^5+I8M0Y<LF"M<
MFBF9*@):"MK90=[=U]C5UM/4#@!!"P*9V=I-WMW7V-76T]0.`$$.D`.3,)0O
ME2Z6+9<LF"N9*IHIG3*>,0)$V=I!FBF9*@``,````&P%``#0GO__2`(```!!
M#E"="IX)1),(E`=&E0:6!4.7!`)G"M[=U]76T]0.`$$+`"P```"@!0``[*#_
M_V@`````00X@G02>`T*3`I0!2@K>W=/4#@!!"TO>W=/4#@```#````#0!0``
MG+7__Q@"````00Y@G0R>"T63"I0)E0B6!P)="M[=U=;3U`X`00L````````@
M````!`8``/B@__^$$````$$.H`5&G52>4P,8!`K=W@X`00L<````*`8``%BQ
M__]4`````$$.$)T"G@%3WMT.`````$````!(!@``E+'__R@!````00Y`G0B>
M!T.3!I0%0Y4$E@-#EP*8`5D*WMW7V-76T]0.`$$+8PK>W=?8U=;3U`X`00L`
M,````(P&``"`LO__E`$```!!#D"=")X'0I,&E`5#E026`T.7`@)5"M[=U]76
MT]0.`$$+````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````D%,````````04P``````````
M`````````0`````````!``````````$`````````>`(````````!````````
M`(("`````````0````````#%`@````````$`````````Y`(````````/````
M`````'T$````````&0````````!`K0$``````!L`````````"``````````:
M`````````$BM`0``````'``````````(``````````0`````````2`(`````
M```%`````````%`/````````!@````````!X!0````````H`````````Q00`
M```````+`````````!@`````````%0````````````````````,`````````
MZ*\!```````"`````````!@&````````%``````````'`````````!<`````
M````,!<````````'`````````!@4````````"``````````8`P````````D`
M````````&`````````#[__]O``````````@`````^?__;P`````7````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````6*T!``````!0
MK0$```````````````````````````!`K0$`````````````````````````
M`````````````$"S`0````````````````!(K0$``````(BR`0``````````
M````````````````````````````6*T!````````````````````````````
MR+(!``````````````````BR`0``````H#P`````````````````````````
M``````````````!0'0```````%`=````````4!T```````!0'0```````%`=
M````````4!T```````!0'0```````%`=````````4!T```````!0'0``````
M`%`=````````4!T```````!0'0```````%`=````````4!T```````!0'0``
M`````%`=````````4!T```````!0'0```````%`=````````4!T```````!0
M'0```````%`=````````4!T```````!0'0```````%`=````````4!T`````
M``!0'0```````%`=````````4!T```````!0'0```````%`=````````4!T`
M``````!0'0```````%`=````````4!T```````!0'0```````%`=````````
M4!T```````!0'0```````%`=````````4!T```````!0'0```````%`=````
M````4!T```````!0'0```````%`=````````4!T```````!0'0```````%`=
M````````4!T```````!0'0```````%`=````````4!T```````!0'0``````
M`%`=````````4!T```````!0'0```````%`=````````4!T```````!0'0``
M`````%`=````````4!T```````!0'0```````%`=````````P+(!```````0
ML@$```````I005(N<&T*````````````5@````````A6````````````````
M```05@```````"!6````````*%8````````P5@```````#A6````````````
M``````!`5@```````$A6``````````````````#060```````$=#0SH@*$YE
M=$)31"!N8C,@,C`R,S$P,#@I(#$P+C4N,`!'0T,Z("AN8C,@,C`R,S$P,#@I
M(#$P+C4N,``D3F5T0E-$.B!C<G0P+E,L=B`Q+C(@,C`Q."\Q,2\R-B`Q-SHS
M-SHT-"!J;V5R9R!%>'`@)``D3F5T0E-$.B!C<G0P+6-O;6UO;BYC+'8@,2XR
M-R`R,#(R+S`V+S(Q(#`V.C4R.C$W('-K<FQL($5X<"`D`"1.971"4T0Z(&-R
M=&DN4RQV(#$N,2`R,#$T+S`X+S$P(#`U.C0W.C,V(&UA='0@17AP("0`)$YE
M=$)31#H@8W)T8F5G:6XN8RQV(#$N,3<@,C`Q."\Q,B\R."`Q.#HQ-SHQ,2!C
M:')I<W1O<R!%>'`@)``D3F5T0E-$.B!C<G1E;F0N4RQV(#$N,2`R,#$T+S`X
M+S$P(#`U.C0W.C,V(&UA='0@17AP("0``/'/`@`````````````````(````
M"`````@````(````&P````$``````````"HJ*B!.;R!,86)E;"!0<F]V:61E
M9"`J*BH``/'/`@`````````````````(````"`````@````(````&P````$`
M`````````"HJ*B!.;R!,86)E;"!0<F]V:61E9"`J*BH``"YS:'-T<G1A8@`N
M:6YT97)P`"YN;W1E+FYE=&)S9"YI9&5N=``N;F]T92YN971B<V0N<&%X`"YH
M87-H`"YD>6YS>6T`+F1Y;G-T<@`N<F5L82YD>6X`+G)E;&$N<&QT`"YT97AT
M`"YR;V1A=&$`+F5H7V9R86UE7VAD<@`N96A?9G)A;64`+FEN:71?87)R87D`
M+F9I;FE?87)R87D`+FIC<@`N9'EN86UI8P`N9V]T`"YG;W0N<&QT`"YD871A
M`"YB<W,`+F-O;6UE;G0`+E-53E=?8W1F````````````````````````````
M````````````````````````````````````````````````````````````
M````"P````$````"```````````"``````````(````````7````````````
M`````````0```````````````````!,````'`````@`````````8`@``````
M`!@"````````&`````````````````````0````````````````````F````
M!P````(`````````,`(````````P`@```````!0````````````````````$
M````````````````````-P````4````"`````````$@"````````2`(`````
M```P`P````````4`````````"``````````$`````````#T````+`````@``
M``````!X!0```````'@%````````V`D````````&`````P````@`````````
M&`````````!%`````P````(`````````4`\```````!0#P```````,4$````
M```````````````!````````````````````30````0````"`````````!@4
M````````&!0````````8`P````````4`````````"``````````8````````
M`%<````$````0@`````````P%P```````#`7````````&`8````````%````
M$P````@`````````&`````````!<`````0````8`````````4!T```````!0
M'0```````#`$```````````````````0`````````!``````````80````$`
M```&`````````(`A````````@"$```````!H-```````````````````$```
M`````````````````&<````!`````@````````#H50```````.A5````````
M;T$```````````````````@```````````````````!O`````0````(`````
M````6)<```````!8EP````````0!```````````````````$````````````
M````````?0````$````"`````````&"8````````8)@```````#$!@``````
M````````````"````````````````````(<````.`````P````````!`K0$`
M`````$"M````````"`````````````````````@`````````"`````````"3
M````#P````,`````````2*T!``````!(K0````````@`````````````````
M```(``````````@`````````GP````$````#`````````%"M`0``````4*T`
M```````(````````````````````"````````````````````*0````&````
M`P````````!8K0$``````%BM````````X`$````````&``````````@`````
M````$`````````"M`````0````,`````````.*\!```````XKP```````+``
M```````````````````(``````````@`````````L@````$````#````````
M`.BO`0``````Z*\````````@`@``````````````````"``````````(````
M`````+L````!`````P`````````(L@$```````BR````````B```````````
M``````````@```````````````````#!````"`````,`````````P+(!````
M``"0L@```````(@```````````````````!`````````````````````Q@``
M``$````P````````````````````D+(````````]````````````````````
M`0`````````!`````````!\````!````,````````````````````,VR````
M````'@$```````````````````$``````````0````````#/`````0``````
M``````````````````#LLP```````(\````````````````````$````````
M`````````````0````,`````````````````````````>[0```````#9````
<`````````````````0``````````````````````
